==> activity-center-api-0.10.16sjq-20191127.045021-2-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/adx/AdvertisingSpaceTypesDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.adx;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;

/**
 * @author shenjiaqing
 * @description
 * @data 2019/11/18
 */
public class AdvertisingSpaceTypesDto implements Serializable {

    /** 广告位类型ID **/
    private Long id;

    /** 广告位类型名称 **/
    private String typeName;

    /** Adx对应类型ID **/
    private String templateId;

    /** Adx平台类型 **/
    private Integer adxType;

    /** 对应样式 **/
    private String styleName;

    private Integer deleteFlag;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTypeName() {
        return typeName;
    }

    public void setTypeName(String typeName) {
        this.typeName = typeName;
    }

    public String getTemplateId() {
        return templateId;
    }

    public void setTemplateId(String templateId) {
        this.templateId = templateId;
    }

    public Integer getAdxType() {
        return adxType;
    }

    public void setAdxType(Integer adxType) {
        this.adxType = adxType;
    }

    public String getStyleName() {
        return styleName;
    }

    public void setStyleName(String styleName) {
        this.styleName = styleName;
    }

    public Integer getDeleteFlag() {
        return deleteFlag;
    }

    public void setDeleteFlag(Integer deleteFlag) {
        this.deleteFlag = deleteFlag;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> activity-center-api-0.10.39sjq-20191206.022539-2-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/adx/AdvertisingSpaceTypesDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.adx;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;

/**
 * @author shenjiaqing
 * @description
 * @data 2019/11/18
 */
public class AdvertisingSpaceTypesDto implements Serializable {

    /** 广告位类型ID **/
    private Long id;

    /** 广告位类型名称 **/
    private String typeName;

    private String slotId;

    /** Adx对应类型ID **/
    private String templateId;

    /** Adx平台类型 **/
    private Integer adxType;

    /** 对应样式 **/
    private String styleName;

    private Integer deleteFlag;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTypeName() {
        return typeName;
    }

    public void setTypeName(String typeName) {
        this.typeName = typeName;
    }

    public String getSlotId() {
        return slotId;
    }

    public void setSlotId(String slotId) {
        this.slotId = slotId;
    }

    public String getTemplateId() {
        return templateId;
    }

    public void setTemplateId(String templateId) {
        this.templateId = templateId;
    }

    public Integer getAdxType() {
        return adxType;
    }

    public void setAdxType(Integer adxType) {
        this.adxType = adxType;
    }

    public String getStyleName() {
        return styleName;
    }

    public void setStyleName(String styleName) {
        this.styleName = styleName;
    }

    public Integer getDeleteFlag() {
        return deleteFlag;
    }

    public void setDeleteFlag(Integer deleteFlag) {
        this.deleteFlag = deleteFlag;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
